=== modified file '.bzrignore'
--- .bzrignore	2014-04-16 18:36:03 +0000
+++ .bzrignore	2014-06-04 09:28:06 +0000
@@ -1,5 +1,7 @@
 # For all dependencies running from source
 ./branches/*
+# Created when uploading the payload
+./.uploaded_version_info
 ./docs/_build
 .deps
 *.egg-info

=== modified file 'juju-deployer/deploy.py'
--- juju-deployer/deploy.py	2014-06-04 08:50:11 +0000
+++ juju-deployer/deploy.py	2014-06-04 09:28:06 +0000
@@ -43,6 +43,7 @@
 import bzrlib
 from bzrlib import (
     builtins,
+    cmd_version_info,
     plugin,
     workingtree,
 )
@@ -572,6 +573,22 @@
     os.environ['JUJU_REPOSITORY'] = repository
 
 
+def generate_version_info(path):
+    orig = sys.stdout
+    try:
+        with open(path, 'w') as f:
+            # Create a file containing the version info from the current
+            # working tree
+            cmd = cmd_version_info.cmd_version_info()
+            def redirect():
+                cmd.outf = f
+
+            # Shame that bzr doesn't provide a better way
+            cmd._setup_outf = redirect
+            cmd.run_argv_aliases(['--python'])
+    finally:
+        sys.stdout = orig
+
 def build_payload(path):
     """Build the payload as a compressed tarball at the given path.
 
@@ -604,6 +621,9 @@
         # We add some more files not under version control. As such, we don't
         # include them in the sha1 (if they matter for the sha1, they should be
         # under version control ;)
+        uploaded_version_info_path = './.uploaded_version_info'
+        generate_version_info(uploaded_version_info_path)
+
         def reset_ids(tarinfo):
             # We don't want to get the uid/gid from the uploader
             tarinfo.uid = tarinfo.gid = 0
@@ -611,14 +631,13 @@
             return tarinfo
 
         with tarfile.open(ball.name, 'a') as tarball:
-            # We use relpaths below to mimick bzr's behavior building a tarball
-            # that can be extracted anywhere.
-            for added_path in ['./.bzrignore']:
+            # Always use relpaths below to mimick bzr's behavior building a
+            # tarball that can be extracted anywhere.
+            for added_path in [uploaded_version_info_path]:
                 tarball.add(added_path, filter=reset_ids)
         # Finally, we compress the resulting tarball
         with gzip.GzipFile(path, 'w') as gz, open(ball.name) as tarball:
             gz.write(tarball.read())
-        
     return sha1.hexdigest()
 
 

